==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/P2SetVisitor.h <==
// public abstract class soot.jimple.spark.sets.P2SetVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_P2SetVisitor_H_
#define _JC_soot_jimple_spark_sets_P2SetVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_Node$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	_jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	_jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$refs	_jc_soot_jimple_spark_sets_P2SetVisitor$refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs	_jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$object	_jc_soot_jimple_spark_sets_P2SetVisitor$object;

typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtable	_jc_soot_jimple_spark_sets_P2SetVisitor$vtable;
typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtype	_jc_soot_jimple_spark_sets_P2SetVisitor$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_P2SetVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_P2SetVisitor$method$getReturnValue$fc088f130a1e5ff0(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *);
extern void _jc_soot_jimple_spark_sets_P2SetVisitor$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *, struct _jc_soot_jimple_spark_pag_Node$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_P2SetVisitor$method_info$getReturnValue$fc088f130a1e5ff0;
extern _jc_method _jc_soot_jimple_spark_sets_P2SetVisitor$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vmethods {
	jboolean	(*getReturnValue$fc088f130a1e5ff0)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *);
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
};

// Vtype
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$refs {
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs {
	jboolean	returnValue;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_P2SetVisitor$object {
	_jc_soot_jimple_spark_sets_P2SetVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vtype	*vtype;
	_jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_P2SetVisitor$vtype _jc_soot_jimple_spark_sets_P2SetVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_P2SetVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_P2SetVisitor$class_object;

#endif	/* _JC_soot_jimple_spark_sets_P2SetVisitor_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/P2SetVisitor.h <==
// public abstract class soot.jimple.spark.sets.P2SetVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_P2SetVisitor_H_
#define _JC_soot_jimple_spark_sets_P2SetVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_Node$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	_jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	_jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$refs	_jc_soot_jimple_spark_sets_P2SetVisitor$refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs	_jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetVisitor$object	_jc_soot_jimple_spark_sets_P2SetVisitor$object;

typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtable	_jc_soot_jimple_spark_sets_P2SetVisitor$vtable;
typedef const struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtype	_jc_soot_jimple_spark_sets_P2SetVisitor$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_P2SetVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_P2SetVisitor$method$getReturnValue$fc088f130a1e5ff0(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_sets_P2SetVisitor$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_P2SetVisitor$method_info$getReturnValue$fc088f130a1e5ff0;
extern _jc_method _jc_soot_jimple_spark_sets_P2SetVisitor$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vmethods {
	jboolean	(*getReturnValue$fc088f130a1e5ff0)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *) _JC_JCNI_ATTR;
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetVisitor$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
};

// Vtype
struct _jc_soot_jimple_spark_sets_P2SetVisitor$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$refs {
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs {
	jboolean	returnValue;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_P2SetVisitor$object {
	_jc_soot_jimple_spark_sets_P2SetVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vtype	*vtype;
	_jc_soot_jimple_spark_sets_P2SetVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_P2SetVisitor$vtype _jc_soot_jimple_spark_sets_P2SetVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_P2SetVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_P2SetVisitor$class_object;

#endif	/* _JC_soot_jimple_spark_sets_P2SetVisitor_H_ */
